@@ -1,19 +1,12 @@
 CLI_CONFIG = {
-    "acct_file": {
-        "positional": True,
-        "os": "ACCT_FILE",
-        "subcommands": ["encrypt", "decrypt"],
-    },
+    "input_file": {"positional": True, "subcommands": ["encrypt", "decrypt"],},
     "acct_key": {"os": "ACCT_KEY", "subcommands": ["encrypt", "decrypt"]},
     "crypto_plugin": {"subcommands": ["encrypt", "decrypt"]},
     "output": {"source": "rend", "subcommands": ["decrypt"]},
     "output_file": {"subcommands": ["encrypt"]},
 }
 CONFIG = {
-    "acct_file": {
-        "default": None,
-        "help": "The file to encrypt, a new file will be created.",
-    },
+    "acct_file": {"default": None, "help": "An encrypted acct file",},
     "acct_key": {
         "default": None,
         "help": "The key to encrypt the file with, if no key is passed a key will be generated and displayed on after the encrypted file is created",
@@ -22,7 +15,6 @@ CONFIG = {
         "default": "fernet",
         "help": "The crypto plugin to use with acct",
     },
-    "output": {"default": "yaml", "help": "The outputter to use to display data",},
     "output_file": {"default": None, "help": "The output file name when encrypting"},
 }
 SUBCOMMANDS = {
